@@ -16,7 +16,7 @@ class S3FileInput(ClearableFileInput):
         '<div class="s3file" data-url="{signing_url}" data-target="{element_id}">\n'
         '    <a class="link" target="_blank" href="{file_url}">{file_url}</a>\n'
         '    <a class="remove" href="javascript: void(0)">{remove}</a>\n'
-        '    <input type="hidden" value="initial" id="{element_id}" name="{name}" />\n'
+        '    <input type="hidden" value="{value}" id="{element_id}" name="{name}" />\n'
         '    <input type="file" class="fileinput" id="s3-{element_id}" />\n'
         '    <div class="progress progress-striped active">\n'
         '        <div class="progress-bar"></div>\n'
@@ -33,11 +33,17 @@ class S3FileInput(ClearableFileInput):
         else:
             file_url = ''
 
+        if file_url:
+            input_value = 'initial'
+        else:
+            input_value = ''
+
         output = self.template.format(
             signing_url=self.signing_url,
             file_url=file_url,
             element_id=element_id or '',
             name=name,
+            value=input_value,
             remove=ugettext('remove')
         )
 
